@@ -217,6 +217,18 @@ impl LineFilterConfig {
         self
     }
 
+    /// Skip lines inside any MkDocs container (admonitions or content tabs)
+    ///
+    /// This is a convenience method that enables both `skip_admonitions` and
+    /// `skip_content_tabs`. MkDocs containers use 4-space indented content
+    /// which may need special handling to preserve structure.
+    #[must_use]
+    pub fn skip_mkdocs_containers(mut self) -> Self {
+        self.skip_admonitions = true;
+        self.skip_content_tabs = true;
+        self
+    }
+
     /// Skip lines inside definition lists (:  definition)
     ///
     /// Definition lists have special formatting that rules should
@@ -443,6 +455,17 @@ impl<'a> FilteredLinesBuilder<'a> {
         self
     }
 
+    /// Skip lines inside any MkDocs container (admonitions or content tabs)
+    ///
+    /// This is a convenience method that enables both `skip_admonitions` and
+    /// `skip_content_tabs`. MkDocs containers use 4-space indented content
+    /// which may need special handling to preserve structure.
+    #[must_use]
+    pub fn skip_mkdocs_containers(mut self) -> Self {
+        self.config = self.config.skip_mkdocs_containers();
+        self
+    }
+
     /// Skip lines inside definition lists (:  definition)
     #[must_use]
     pub fn skip_definition_lists(mut self) -> Self {
