@@ -312,6 +312,7 @@ impl Rule for MD064NoMultipleConsecutiveSpaces {
             return Ok(vec![]);
         }
 
+        // Config is already correct - engine applies inline overrides before calling check()
         let mut warnings = Vec::new();
         let code_spans: Arc<Vec<crate::lint_context::CodeSpan>> = ctx.code_spans();
         let line_index = &ctx.line_index;
@@ -1432,4 +1433,76 @@ Normal paragraph.
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Should allow 2 spaces after superscript");
     }
+
+    #[test]
+    fn test_inline_config_allow_sentence_double_space() {
+        // Issue #364: Inline configure-file comments should work
+        // Tests the automatic inline config support via Config::merge_with_inline_config
+
+        let rule = MD064NoMultipleConsecutiveSpaces::new(); // Default config (disabled)
+
+        // Without inline config, should flag
+        let content = "`<svg>`.  Fortunately";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+        assert_eq!(result.len(), 1, "Default config should flag double spaces");
+
+        // With inline config, should allow
+        // Simulate engine behavior: parse inline config, merge with base config, recreate rule
+        let content = r#"<!-- rumdl-configure-file { "MD064": { "allow-sentence-double-space": true } } -->
+
+`<svg>`.  Fortunately"#;
+        let inline_config = crate::inline_config::InlineConfig::from_content(content);
+        let base_config = crate::config::Config::default();
+        let merged_config = base_config.merge_with_inline_config(&inline_config);
+        let effective_rule = MD064NoMultipleConsecutiveSpaces::from_config(&merged_config);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = effective_rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Inline config should allow double spaces after sentence"
+        );
+
+        // Also test with markdownlint prefix
+        let content = r#"<!-- markdownlint-configure-file { "MD064": { "allow-sentence-double-space": true } } -->
+
+**scalable**.  Pick"#;
+        let inline_config = crate::inline_config::InlineConfig::from_content(content);
+        let merged_config = base_config.merge_with_inline_config(&inline_config);
+        let effective_rule = MD064NoMultipleConsecutiveSpaces::from_config(&merged_config);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = effective_rule.check(&ctx).unwrap();
+        assert!(result.is_empty(), "Inline config with markdownlint prefix should work");
+    }
+
+    #[test]
+    fn test_inline_config_allow_sentence_double_space_issue_364() {
+        // Full test case from issue #364
+        // Tests the automatic inline config support via Config::merge_with_inline_config
+
+        let content = r#"<!-- rumdl-configure-file { "MD064": { "allow-sentence-double-space": true } } -->
+
+# Title
+
+what the font size is for the toplevel `<svg>`.  Fortunately, librsvg
+
+And here is where I want to say, SVG documents are **scalable**.  Pick
+
+That's right, no `width`, no `height`, no `viewBox`.  There is no easy
+
+**SVG documents are scalable**.  That's their whole reason for being!"#;
+
+        // Simulate engine behavior: parse inline config, merge with base config, recreate rule
+        let inline_config = crate::inline_config::InlineConfig::from_content(content);
+        let base_config = crate::config::Config::default();
+        let merged_config = base_config.merge_with_inline_config(&inline_config);
+        let effective_rule = MD064NoMultipleConsecutiveSpaces::from_config(&merged_config);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = effective_rule.check(&ctx).unwrap();
+        assert!(
+            result.is_empty(),
+            "Issue #364: All sentence-ending double spaces should be allowed with inline config. Found {} warnings",
+            result.len()
+        );
+    }
 }
