@@ -40,7 +40,7 @@ Another very very very very very very very very very very very very very very ve
     };
 
     let rule = MD013LineLength::from_config_struct(config);
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
 
     // Check for warnings
     let warnings = rule.check(&ctx).unwrap();
@@ -52,7 +52,7 @@ Another very very very very very very very very very very very very very very ve
     let fixed_content = rule.fix(&ctx).unwrap();
 
     // Check the fixed content for remaining warnings
-    let ctx_fixed = LintContext::new(&fixed_content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx_fixed = LintContext::new(&fixed_content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let remaining_warnings = rule.check(&ctx_fixed).unwrap();
 
     // The table row should still have a warning because it can't be reflowed
@@ -107,7 +107,7 @@ fn test_mixed_rules_fix_counting() {
     let md013 = MD013LineLength::from_config_struct(md013_config);
     let md009 = MD009TrailingSpaces::default();
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
 
     // Check MD013 warnings
     let md013_warnings = md013.check(&ctx).unwrap();
@@ -119,13 +119,13 @@ fn test_mixed_rules_fix_counting() {
 
     // Fix MD009 (trailing spaces)
     let fixed_by_md009 = md009.fix(&ctx).unwrap();
-    let ctx_after_md009 = LintContext::new(&fixed_by_md009, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx_after_md009 = LintContext::new(&fixed_by_md009, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let md009_remaining = md009.check(&ctx_after_md009).unwrap();
     assert_eq!(md009_remaining.len(), 0, "All trailing spaces should be fixed");
 
     // Fix MD013 (line length)
     let fixed_by_md013 = md013.fix(&ctx_after_md009).unwrap();
-    let ctx_after_md013 = LintContext::new(&fixed_by_md013, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx_after_md013 = LintContext::new(&fixed_by_md013, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let md013_remaining = md013.check(&ctx_after_md013).unwrap();
     assert_eq!(md013_remaining.len(), 1, "Table header should still be too long");
 
