@@ -26,7 +26,7 @@ Regular text after footnotes."#;
 
     // Test with MD031 (blanks around fences/blocks)
     let rule_031 = MD031BlanksAroundFences::default();
-    let ctx = LintContext::new(content, MarkdownFlavor::MkDocs);
+    let ctx = LintContext::new(content, MarkdownFlavor::MkDocs, None);
     let warnings = rule_031.check(&ctx).unwrap();
 
     // Footnote definitions should not trigger MD031
@@ -80,7 +80,7 @@ More content after tabs."#;
 
     // Test with MD031 (blanks around fences)
     let rule_031 = MD031BlanksAroundFences::default();
-    let ctx = LintContext::new(content, MarkdownFlavor::MkDocs);
+    let ctx = LintContext::new(content, MarkdownFlavor::MkDocs, None);
     let warnings = rule_031.check(&ctx).unwrap();
 
     // Tab markers themselves might need blank lines around them,
@@ -119,7 +119,7 @@ You can also use [custom text][mymodule.utils.helper]."#;
 
     // Test with MD052 (reference links) - crossrefs are special
     let rule_052 = MD052ReferenceLinkImages::default();
-    let ctx = LintContext::new(content, MarkdownFlavor::MkDocs);
+    let ctx = LintContext::new(content, MarkdownFlavor::MkDocs, None);
     let warnings = rule_052.check(&ctx).unwrap();
 
     // Cross-references should not be flagged as undefined references
@@ -163,7 +163,7 @@ Some text with a footnote[^2] and a cross-reference to [MyClass][].
 ??? tip "Collapsible Tip"
     This collapsible section has content."#;
 
-    let ctx = LintContext::new(content, MarkdownFlavor::MkDocs);
+    let ctx = LintContext::new(content, MarkdownFlavor::MkDocs, None);
 
     // Test with MD031
     let rule_031 = MD031BlanksAroundFences::default();
@@ -190,7 +190,7 @@ fn test_standard_flavor_no_mkdocs_features() {
 !!! note
     This looks like an admonition but isn't."#;
 
-    let ctx = LintContext::new(content, MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, MarkdownFlavor::Standard, None);
 
     // In standard flavor, these should be treated as regular text
     // and may trigger various rules
@@ -220,7 +220,7 @@ Text with reference[^complex].
 
 Regular text."#;
 
-    let ctx = LintContext::new(content, MarkdownFlavor::MkDocs);
+    let ctx = LintContext::new(content, MarkdownFlavor::MkDocs, None);
 
     // Complex footnote content should be properly handled
     let rule_031 = MD031BlanksAroundFences::default();
@@ -250,7 +250,7 @@ fn test_nested_tabs() {
 
     Different content."#;
 
-    let ctx = LintContext::new(content, MarkdownFlavor::MkDocs);
+    let ctx = LintContext::new(content, MarkdownFlavor::MkDocs, None);
 
     // Nested tabs should be recognized
     let rule_031 = MD031BlanksAroundFences::default();
@@ -276,7 +276,7 @@ fn test_mkdocstrings_with_yaml_options() {
 
 Regular text continues here."#;
 
-    let ctx = LintContext::new(content, MarkdownFlavor::MkDocs);
+    let ctx = LintContext::new(content, MarkdownFlavor::MkDocs, None);
 
     // MD005 - Should not flag YAML lists as markdown list indentation issues
     let rule_005 = MD005ListIndent::default();
@@ -339,7 +339,7 @@ fn test_mkdocstrings_deeply_nested_yaml() {
 
 Regular documentation continues."#;
 
-    let ctx = LintContext::new(content, MarkdownFlavor::MkDocs);
+    let ctx = LintContext::new(content, MarkdownFlavor::MkDocs, None);
 
     // All rules should ignore the mkdocstrings block
     let rule_005 = MD005ListIndent::default();
